ObsCrashHandler

Trait ObsCrashHandler 

pub trait ObsCrashHandler: Send {
    // Required method
    fn handle_crash(&self, message: String);
}
Trait for handling OBS crashes. This is called whenever OBS encounters a fatal error and crashes. Implementors can define custom behavior for crash handling, such as logging the error, showing a dialog, or sending reports.

MAKE SURE that the handle_crash function does the least amount of work possible, as it is called in a crash context where many resources may be unavailable.

Required Methods

fn handle_crash(&self, message: String)

Handles an OBS crash with the given message. YOU MUST MAKE SURE that this function does the least amount of work possible!

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors